package com.deltadna.android.sdk;

import com.deltadna.android.sdk.helpers.NotStartedException;
/**
 * Helper class to add a transaction event.
 */
public class TransactionBuilder{
	/**
	 * Constructor.
	 */
	protected TransactionBuilder(){}
	/**
	 * Buy some virtual currency.
	 * 
	 * @param transactionName The transaction name.
	 * @param realCurrencyType The real currency type.
	 * @param realCurrencyAmount The real currency amount.
	 * @param virtualCurrencyName The virtual currency name.
	 * @param virtualCurrencyType The virtual currency type.
	 * @param virtualCurrencyAmount The virtual currency amount.
	 * @param transactionReceipt Transaction receipt token.
	 * 
	 * @throws NotStartedException
	 */
	public void buyVirtualCurrency(String transactionName,
			String realCurrencyType,
			int realCurrencyAmount,
			String virtualCurrencyName,
			String virtualCurrencyType,
			int virtualCurrencyAmount,
			String transactionReceipt) throws NotStartedException{
		EventBuilder eventParams = new EventBuilder()
		.addParam("transactionType", "PURCHASE")
		.addParam("transactionName", transactionName)
		.addParam("productsSpent", new ProductBuilder()
		.addRealCurrency(realCurrencyType, realCurrencyAmount))
		.addParam("productsReceived", new ProductBuilder()
		.addVirtualCurrency(virtualCurrencyName, virtualCurrencyType, virtualCurrencyAmount))
		.addParam("transactionReceipt", transactionReceipt);

		DDNA.inst().recordEvent("transaction", eventParams);
	}
}
