package com.deltadna.android.sdk.helpers;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
/**
 * Wrapper around MD5 hashing functionality.
 */
public class MD5{
	/**
	 * Hashes the given source string.
	 * 
	 * @param source The source string to hash.
	 * 
	 * @return The hex encoded hashed string.
	 */
	static public String getMd5String(String source){
		byte[] hash;

		//Convert the String into an array of bytes.
		byte[] buffer = source.getBytes();

		//Create the hash value from the array of bytes.
		hash = MD5.computeHash(buffer);

		return Utils.bytesToHex(hash);
	}
	/**
	 * Hashes the given source bytes.
	 * 
	 * @param buffer The source bytes to hash.
	 * 
	 * @return The hash encoded bytes.
	 */
	static public byte[] computeHash(byte[] buffer){
		return computeHash(buffer, 0, buffer.length);
	}
	/**
	 * Hashes the given run of source bytes.
	 * 
	 * @param buffer The source bytes to hash.
	 * @param offset Start offset.
	 * @param count Byte count.
	 * 
	 * @return The hash encoded bytes.
	 */
	static public byte[] computeHash(byte[] buffer, int offset, int count){
		byte[] result = null;
		
	    final String MD5 = "MD5";
	    try {
	        // Create MD5 Hash
	        MessageDigest digest = java.security.MessageDigest.getInstance(MD5);
	        digest.update(buffer);
	        
	        result = digest.digest();
	    } catch (NoSuchAlgorithmException e) { e.printStackTrace();}
	    
	    return result;
	}
	/**
	 * Hashes the given source input stream.
	 * 
	 * @param inputStream The source input stream to hash.
	 * 
	 * @return The hash encoded bytes.
	 */
	static public byte[] computeHash(InputStream inputStream){
		byte[] result = null;

		try {
			ByteArrayOutputStream bytes = new ByteArrayOutputStream();
			byte[] buffer = new byte[4096];
			
			int count = inputStream.read(buffer, 0, 4096);
			while(count > 0){
				bytes.write(buffer, 0, count);
				count = inputStream.read(buffer, 0, 4096);
			}

			buffer = bytes.toByteArray();
			
			result = computeHash(buffer);
		} catch (IOException e) {e.printStackTrace();}
		
		return result;
	}
}

